﻿(function () {
    "use strict";

    var page = WinJS.UI.Pages.define("/pages/fotos/fotos.html", {
        ready: function (element, options) {
            loadListViewControl();
        },

        // This function updates the page layout in response to viewState changes
        updateLayout: function (element, viewState) {
            var listView = document.getElementById("listviewDiv").winControl;
            if (viewState === Windows.UI.ViewManagement.ApplicationViewState.snapped) {
                listView.layout = new WinJS.UI.ListLayout();
            } else {
                listView.layout = new WinJS.UI.GridLayout();
            }
            listView.layout.backdropColor = "#333333"; // Need to match up with the item background color.
        },

        unload: function () {
            // Remove override styles
            var contentHost = document.getElementById("contentHost");
            WinJS.Utilities.removeClass(contentHost, "gallery");
        }
    });

    function loadListViewControl() {
        //Construimos el origen de datos para obtener las imagenes
        var library = Windows.Storage.KnownFolders.picturesLibrary;
        var queryOptions = new Windows.Storage.Search.QueryOptions;
        queryOptions.folderDepth = Windows.Storage.Search.FolderDepth.deep;
        queryOptions.indexerOption = Windows.Storage.Search.IndexerOption.useIndexerWhenAvailable;

        var fileQuery = library.createFileQueryWithOptions(queryOptions);
        var dataSourceOptions = {
            mode: Windows.Storage.FileProperties.ThumbnailMode.picturesView,
            requestedThumbnailSize: 190,
            thumbnailOptions: Windows.Storage.FileProperties.ThumbnailOptions.none
        };

        var dataSource = new WinJS.UI.StorageDataSource(fileQuery, dataSourceOptions);
        // Todo el codigo de arriba se puede simplificar con la siguiente línea 
        // Pero, preferí usar la “forma larga” para mostrar todas las opciones
        // var dataSource = new WinJS.UI.StorageDataSource("Pictures");
        // obtenemos el DIV anterior, para utilizarlo como contenedor
        var container = document.getElementById("listviewDiv");
        var listViewOptions = {
            itemDataSource: dataSource,
            itemTemplate: storageRenderer, //Explicado mas abajo
            layout: new WinJS.UI.GridLayout(),
            selectionMode: "single"
        };
        // Convertimos nuestro DIV en un ListView
        new WinJS.UI.ListView(container, listViewOptions);
    };

    function storageRenderer(itemPromise, element) {
        var img;
        if (element === null) {
            // Creamos un div con class FileTemplate, y adentro le metemos una imagen <img>
            element = document.createElement("div");
            element.className = "FileTemplate";
            element.appendChild(document.createElement("img"));
        }
        img = element.querySelector("img");
        img.style.opacity = 0;

        return {
            // retornamos el template
            element: element,
            // y la promesa de que se va a completar la carga de la imagen
            renderComplete: itemPromise.then(function (item) {
                // devolvemos el item cuando esta listo
                return item.ready;
            }).then(function (item) {
                // luego de tener el item listo, seteamos el source (src) a la imagen
                return WinJS.UI.StorageDataSource.loadThumbnail(item, img);
            })
        };
    }
})();
